/**
 * Copyright (c) 2020-present, Goldman Sachs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { LegendQuery } from '@finos/legend-application-query';
import { WebConsole, } from '@finos/legend-shared';
import { DSL_DataSpace_GraphManagerPreset as DSL_DataSpace_GraphManagerPreset, DSL_DataSpace_LegendQueryApplicationPlugin as DSL_DataSpace_LegendQueryApplicationPlugin, } from '@finos/legend-extension-dsl-data-space';
import { DSL_Text_GraphManagerPreset } from '@finos/legend-extension-dsl-text';
import { DSL_Diagram_GraphManagerPreset } from '@finos/legend-extension-dsl-diagram';
import { DSL_ExternalFormat_GraphPreset } from '@finos/legend-graph';
import { DSL_PersistenceCloud_GraphManagerPreset } from '@finos/legend-extension-dsl-persistence-cloud';
import { STO_ServiceStore_GraphManagerPreset } from '@finos/legend-extension-store-service-store';
import { FMT_JSONSchema_GraphManagerPreset } from '@finos/legend-extension-format-json-schema';
import { DSL_Persistence_GraphManagerPreset } from '@finos/legend-extension-dsl-persistence';
import { DSL_Mastery_GraphManagerPreset } from '@finos/legend-extension-dsl-mastery';
import { DSL_Service_LegendQueryApplicationPlugin } from '@finos/legend-extension-dsl-service';
export class LegendQueryWebApplication {
    static getPresetCollection() {
        return [
            // graph managers
            new DSL_Text_GraphManagerPreset(),
            new DSL_Diagram_GraphManagerPreset(),
            new DSL_DataSpace_GraphManagerPreset(),
            new DSL_ExternalFormat_GraphPreset(),
            new DSL_Persistence_GraphManagerPreset(),
            new DSL_Mastery_GraphManagerPreset(),
            new DSL_PersistenceCloud_GraphManagerPreset(),
            new FMT_JSONSchema_GraphManagerPreset(),
            new STO_ServiceStore_GraphManagerPreset(),
        ];
    }
    static getPluginCollection() {
        return [
            // application
            new DSL_Service_LegendQueryApplicationPlugin(),
            new DSL_DataSpace_LegendQueryApplicationPlugin(),
            // loggers
            new WebConsole(),
        ];
    }
    static run(baseUrl) {
        LegendQuery.create()
            .setup({ baseUrl })
            .withPresets(LegendQueryWebApplication.getPresetCollection())
            .withPlugins(LegendQueryWebApplication.getPluginCollection())
            .start()
            .catch((e) => {
            throw e;
        });
    }
}
//# sourceMappingURL=index.js.map